#' batea_s

#' batea_s
#' @param dataset list or tibble
#' @param m_tilde name of the column representative of the prediction
#' @param y_tilde name of the column representative of the output
#' @param phi_h1  hyper-parameters of phi_h1
#' @param alg chosen algorithm for mcmc
#' @param niter number of iteration
#' @keywords batqa
#' @export
#' @details Compute the batea assuming structural and remant only exist
#' @examples
#' \dontrun{
#' batea_s()
#' }
batea_s <- function(dataset,m_tilde,y_tilde,phi_h1,alg="mh_pw",niter=1000){

  # prior
  prior_ <- bato::prior(

    name = c("phi_h1"),

    hyperpar = function(){
      res <- list(
          phi_h1 = phi_h1)

       return(res)
     },

     init = function(hyperpar){
       res <- list(
         phi_h1 = hyperpar[["phi_h1"]]$mean)
       return(res)
     },

    density = function(x,v, hyperpar){
       d_phi_h1 = dnorm(x[["phi_h1"]], mean= v[["phi_h1"]], sd = hyperpar[["phi_h1"]]$sd, log =TRUE)
       return(d_phi_h1)
    },

    sampler = function(n,v,hyperpar){
      r_phi_h1 <- rnorm(n, mean= v[["phi_h1"]], sd = hyperpar[["phi_h1"]]$sd)
      res <- list()
      res[["phi_h1"]] <- abs(r_phi_h1)
      return(res)
    }
  )

  # bato object
  # remark: any kind of loop (if,for,...) must be avoided
  hello <- bato::bato(

      mcmc_par <- list(alg=alg,niter=niter),

      prior = prior_,

      parameters = function(dataset,m_tilde,y_tilde,v,n=1,prior,vec=NULL) {
        res <- list()
        prior$sampler(n=n,v=v,hyperpar=prior$hyperpar())
        prior$piece(vec=vec)
        sig_h <- expr_sig_h_ts_1par(m_tilde_=dataset[[m_tilde]],phi_h1=prior$get_gen()[["phi_h1"]])

        res[["sig_h"]] <- sig_h

        return(res)
      },

      likelihoods = function(dataset,m_tilde,y_tilde,v,param,prior,vec=NULL){

        par <- param(dataset=dataset,m_tilde=m_tilde,y_tilde=y_tilde,v=v,prior=prior,vec=vec)

        # likelihoods
        ll1 <- dnorm(x=dataset[[y_tilde]], mean=dataset[[m_tilde]],sd=sqrt(par[["sig_h"]]^2),log = TRUE)

        res <- sum(ll1,na.rm=TRUE)

        return(res)
      }

  )

  # process
  hello$mcmc(dataset=dataset,m_tilde=m_tilde,y_tilde=y_tilde)

  # results
  res <- list(
    type = "batea_r",
    time_lag = hello$get_time_lag(),
    name = c("phi_h1"),
    distrib = c("norm"),
    hyperpar = list(phi_h1=phi_h1),
    phi = hello$get_prior_gen(),
    al = hello$get_alpha(),
    mcmc_par = list(alg=alg,niter=niter)
  )

  class(res) <- c("batea",class(res))

  return(res)




}
