#' expr_sig_f_ts_3par

#' expr_sig_f_ts_3par
#' @param x_tilde_ x_tilde timeseries
#' @param phi_f1 phi_f1 value
#' @param phi_f2 phi_f2 value
#' @param phi_f3 phi_f3 value
#' @keywords batqa
#' @export
#' @details Calulates the timeserie of the a priori standard deviation parameter of the input error
#' @examples
#' \dontrun{
#' expr_sig_f_ts_3par()
#' }
expr_sig_f_ts_3par <- function(x_tilde_,phi_f1,phi_f2,phi_f3){
    res <- rep(NA,length(x_tilde_))
    res[which(x_tilde_ <= abs(phi_f3))] <- abs(phi_f1)
    res[which(x_tilde_ > abs(phi_f3))] <- abs(phi_f2)*x_tilde_[which(x_tilde_ > abs(phi_f3))]
    return(res)
}

#' expr_sig_f_ts_2par

#' expr_sig_f_ts_2par
#' @param x_tilde_ x_tilde timeseries
#' @param phi_f1 phi_f1 value
#' @param phi_f2 phi_f2 value
#' @keywords batqa
#' @export
#' @details Calulates the timeserie of the a priori standard deviation parameter of the input error
#' @examples
#' \dontrun{
#' expr_sig_f_ts_2par()
#' }
expr_sig_f_ts_2par <- function(x_tilde_,phi_f1,phi_f2){
    res <- abs(phi_f1) + abs(phi_f2)*x_tilde_
    return(res)
}

#' expr_sig_f_ts_1par

#' expr_sig_f_ts_1par
#' @param x_tilde_ x_tilde timeseries
#' @param phi_f1 phi_f1 value
#' @keywords batqa
#' @export
#' @details Calulates the timeserie of the a priori standard deviation parameter of the input error
#' @examples
#' \dontrun{
#' expr_sig_f_ts_2par()
#' }
expr_sig_f_ts_1par <- function(x_tilde_,phi_f1){
    res <- abs(phi_f1)*x_tilde_
    return(res)
}

#' expr_sig_g_ts_3par

#' expr_sig_g_ts_3par
#' @param y_tilde_ y_tilde timeseries
#' @param phi_g1 phi_g1 value
#' @param phi_g2 phi_g2 value
#' @param phi_g3 phi_g3 value
#' @keywords bato
#' @export
#' @details Calulates the timeserie of the a priori standard deviation parameter of the output error
#' @examples
#' \dontrun{
#' expr_sig_g_ts_3par()
#' }
expr_sig_g_ts_3par <- function(y_tilde_,phi_g1,phi_g2,phi_g3){
    res <- rep(NA,length(y_tilde_))
    res[which(y_tilde_ <= abs(phi_g3))] <- abs(phi_g1)
    res[which(y_tilde_ > abs(phi_g3))] <- abs(phi_g2)*y_tilde_[which(y_tilde_ > abs(phi_g3))]
    return(res)
}

#' expr_sig_g_ts_2par

#' expr_sig_g_ts_2par
#' @param y_tilde_ y_tilde timeseries
#' @param phi_g1 phi_g1 value
#' @param phi_g2 phi_f2 value
#' @keywords batqa
#' @export
#' @details Calulates the timeserie of the a priori standard deviation parameter of the output error
#' @examples
#' \dontrun{
#' expr_sig_g_ts_2par()
#' }
expr_sig_g_ts_2par <- function(y_tilde_,phi_g1,phi_g2){
    res <- abs(phi_g1) + abs(phi_g2)*y_tilde_
    return(res)
}

#' expr_sig_g_ts_1par

#' expr_sig_g_ts_1par
#' @param y_tilde_ y_tilde timeseries
#' @param phi_g1 phi_g1 value
#' @keywords batqa
#' @export
#' @details Calulates the timeserie of the a priori standard deviation parameter of the output error
#' @examples
#' \dontrun{
#' expr_sig_g_ts_1par()
#' }
expr_sig_g_ts_1par <- function(y_tilde_,phi_g1){
    res <- abs(phi_g1)*y_tilde_
    return(res)
}

#' expr_sig_h_ts_1par

#' expr_sig_h_ts_1par
#' @param m_tilde_ m_tilde timeseries
#' @param phi_h1 phi_h1 value
#' @keywords bato
#' @export
#' @details Calulates the timeserie of the a priori standard deviation parameter of the structural error
#' @examples
#' \dontrun{
#' expr_sig_h_ts_1par()
#' }
expr_sig_h_ts_1par <- function(m_tilde_,phi_h1){
    res <- abs(phi_h1)*m_tilde_
    return(res)
}

#' expr_sig_h_ts_2par

#' expr_sig_h_ts_2par
#' @param m_tilde_ m_tilde timeseries
#' @param phi_h1 phi_h1 value
#' @param phi_h2 phi_h2 value
#' @keywords bato
#' @export
#' @details Calulates the timeserie of the a priori standard deviation parameter of the structural error
#' @examples
#' \dontrun{
#' expr_sig_h_ts_2par()
#' }
expr_sig_h_ts_2par <- function(m_tilde_,phi_h1,phi_h2){
    res <- abs(phi_h1) + abs(phi_h2)*m_tilde_
    return(res)
}
