#' hist_par

#' hist_par
#' @param batea_obj batea_obj
#' @param burnin percentage by default 30 percent
#' @param BURNIN Boolean
#' @param PRIOR Boolean
#' @param DESKTOP boolean
#' @param path path tempdir() by default
#' @param name filename by default 'posterior_host'
#' @param width_mm width in mm, 200 by default
#' @param height_mm height in mm, 200 by default

#' @keywords batqa
#' @export
#' @examples
#' \dontrun{
#' hist_par()
#' }
hist_par <- function(batea_obj,burnin=30,BURNIN=TRUE,PRIOR=TRUE,DESKTOP=TRUE,path=tempdir(),name="posterior_hist_",width_mm=200,height_mm=200){

  if (inherits(batea_obj,"batea")){

    par <- get_posterior(batea_obj,burnin=burnin,BURNIN=BURNIN)

    histogram_ <- stats::setNames(vector("list", length(batea_obj$name)), batea_obj$name)
    x_ <- stats::setNames(vector("list", length(batea_obj$name)), batea_obj$name)
    if (PRIOR) y_ <- stats::setNames(vector("list", length(batea_obj$name)), batea_obj$name)

    for (i in 1:length(batea_obj$name)){

      x_ <- seq(min(par[[batea_obj$name[i]]]),max(par[[batea_obj$name[i]]]),length=length(par[[batea_obj$name[i]]]))
      if (PRIOR) {
        fun <- ddistrib(batea_obj$distrib[[i]])
        y_ <- fun(x_,batea_obj$hyperpar[[batea_obj$name[i]]][[1]],batea_obj$hyperpar[[batea_obj$name[i]]][[2]])
      }
      histogram_ <- graphics::hist(par[[batea_obj$name[i]]], prob = T)
      grDevices::dev.off()

      if (!DESKTOP) {
          filename <- normalizePath(file.path(path,paste0(name,"_",batea_obj$type,"_",batea_obj$name[i],".tiff")),mustWork = FALSE)
          grDevices::tiff(filename = filename, width = width_mm, height = height_mm,
                units = "mm", pointsize = 12,
                compression = "lzw",
                bg = "transparent", res = 300)

        } else grDevices::dev.new()


      if (PRIOR) {
        ylim <- c(0, max(histogram_$density,y_))
      } else ylim <- c(0, max(histogram_$density))

      graphics::hist(par[[batea_obj$name[i]]],
                     prob = T,
                     col = "dark grey",
                     xlim=c(min(par[[batea_obj$name[i]]]),max(par[[batea_obj$name[i]]])),
                     ylim =ylim,
           main = paste0(batea_obj$name[i]," distribution"),
           xlab = "posterior estimate")
      if (PRIOR) graphics::lines(x_,y_)

      if (!DESKTOP) {
        grDevices::dev.off()
        print(filename)
      } else {}


    }
  } else {stop("batea_obj required to be class batea")}


  return(TRUE)

}


ddistrib <- function(distrib){

  res <- switch(distrib,
    "norm"     = stats::dnorm,
    "invchisq" = dinvchisq,
    stop("distribution 'distrib' not yet included", distrib))

  return(res)
}


#' plot_par

#' plot_par
#' @param batea_obj batea_obj
#' @param burnin percentage by default 30 percent
#' @param BURNIN Boolean
#' @param DESKTOP boolean
#' @param path path tempdir() by default
#' @param width_mm width in mm, 200 by default
#' @param height_mm height in mm, 200 by default
#' @keywords batqa
#' @export
#' @examples
#' \dontrun{
#' plot_par()
#' }
plot_par <- function(batea_obj,burnin=30,BURNIN=TRUE,DESKTOP=TRUE,path=tempdir(),width_mm=200,height_mm=200){

  if (inherits(batea_obj,"batea")){

    par <- get_posterior(batea_obj,burnin=burnin,BURNIN=BURNIN)

    for (i in 1:length(batea_obj$name)){

      if (!DESKTOP) {

          filename <- normalizePath(file.path(path,paste0("posterior_iter_",batea_obj$type,"_",batea_obj$name[i],".tiff")),mustWork = FALSE)
          grDevices::tiff(filename = filename, width = width_mm, height = height_mm,
                units = "mm", pointsize = 12,
                compression = "lzw",
                bg = "transparent", res = 300)

        } else grDevices::dev.new()

      graphics::plot(par[[batea_obj$name[i]]],
           main = paste0(batea_obj$name[i]," sample"),
           xlab = "iteration",
           ylab = "value")


    }

    if (!DESKTOP) {
      grDevices::dev.off()
      print(filename)
    } else {}


  } else {stop("batea_obj required to be class batea")}

  return(TRUE)

}
