
#' get_posterior

#' get_posterior
#' @param batea_obj batea_obj
#' @param burnin burnin ratio
#' @param BURNIN boolean
#' @keywords batqa
#' @export
#' @examples
#' \dontrun{
#' get_posterior()
#' }
get_posterior <- function(batea_obj,burnin=30,BURNIN=TRUE){

  if (inherits(batea_obj,"batea")){

      if (!BURNIN) {
        burnin <- 0
      } else if (BURNIN){
        burnin <- burnin
      } else stop("BURNIN required as boolean")

      res <- list()
      for (i in 1:length(batea_obj$name)){
        niter <- length(batea_obj$phi[[batea_obj$name[i]]])
        from <- round(burnin/100*niter)
        to <- niter
        res[[batea_obj$name[i]]] <- batea_obj$phi[[batea_obj$name[i]]][from:to]
      }
      return(res)

  } else {stop("batea_obj required to be class batea")}

}

#' estimate_posterior

#' estimate_posterior
#' @param batea_obj batea_obj
#' @param burnin burnin percentage by default 30
#' @param BURNIN boolean by default 'TRUE'
#' @keywords batqa
#' @export
#' @examples
#' \dontrun{
#' estimate_posterior()
#' }
estimate_posterior <- function(batea_obj,burnin=30,BURNIN=TRUE){

  if (!BURNIN) {
    burnin <- 0
  } else if (BURNIN){
    burnin <- burnin
  } else stop("BURNIN required as boolean")

  if (inherits(batea_obj,"batea")){

      res <- list()
      xposterior <- get_posterior(batea_obj,burnin=burnin,BURNIN=BURNIN)

      for (i in 1:length(batea_obj$name)){

        res[[batea_obj$name[i]]] <- fitdistrib(xposterior[[batea_obj$name[i]]],batea_obj$distrib[[i]])

      }
      return(res)

  } else {stop("batea_obj required to be class batea")}


}

#### soon to be deleted
#' get_param

#' get_param
#' @param batea_obj batea_obj
#' @param burnin burnin ratio
#' @param BURNIN boolean
#' @keywords batqa
#' @export
#' @examples
#' \dontrun{
#' get_param()
#' }
get_param <- function(batea_obj,burnin=0.3,BURNIN=FALSE){

  if (inherits(batea_obj,"batea")){

      if (!BURNIN) {
        burnin <- 0
      } else if (BURNIN){
        burnin <- burnin
      } else stop("BURNIN required as boolean")

      res <- list()
      for (i in 1:length(batea_obj$name)){
        tmp <- batea_obj$phi[[batea_obj$name[i]]]
        from <- round(length(tmp)*burnin)
        to <- length(tmp)
        tmp2 <- cumsum(tmp[from:to])/seq_along(tmp[from:to])
        res[[batea_obj$name[i]]] <- tmp2[length(tmp2)]
      }
      return(res)

  } else {stop("batea_obj required to be class batea")}

}
