#' @importFrom dplyr %>% group_by group_by n arrange mutate
NULL

#' @importFrom stats dnorm rnorm
NULL


#' @export
print.batea <- function(x,...){
  utils::str(x)
}

#' partition

#' partition
#' @param dataset list or tibble
#' @param train ratio for training
#' @param test ratio for testing
#' @param seed seed
#' @keywords batqa
#' @export
#' @examples
#' \dontrun{
#' partition()
#' }
#
partition <- function(dataset,train=0.8,test=0.2,seed=NULL){
  if (!is.null(seed)) set.seed(seed)

  fact <- sample(c("train","test"),dim(dataset)[1],prob=c(train,test),replace=TRUE)
  res <- split(dataset,fact)
  return(res)
}

#############################################
# Scaled inverse chi-squared distribution   #
#############################################

# Theory from wikipedia, https://en.wikipedia.org/wiki/Scaled_inverse_chi-squared_distribution
# Code of rinvchisq and dinvchisq adapted from geoR, cf https://github.com/cran/geoR/blob/master/R/auxiliar.R
# rem1: nu = df/2
# rem2: tau^2 = inverse variance σ^(-2) = scale

rinvchisq <- function(n,df,scale=1/df) {
   res <- (df * scale)/stats::rchisq(n, df = df)
   return(res)
}

dinvchisq <- function(x, df, scale=1/df, LOG = FALSE){
  nu <- df/2
  if(LOG) {
    res <- (ifelse(x > 0, nu*log(nu) - log(gamma(nu)) + nu*log(scale) - (nu+1)*log(x) - (nu*scale/x), NA))
  } else {
    res <- (ifelse(x > 0, (((nu)^(nu))/gamma(nu)) * (scale^nu) * (x^(-(nu+1))) * exp(-nu*scale/x), NA))
  }
  return(res)
}

pinvchisq <- function(x, df, scale=1/df){
  nu <- df/2
  res <- ifelse(x > 0,stats::pgamma(nu,scale*nu/x)/gamma(nu), NA)
  return(res)
}

fit_invchisq <- function(x){

  if (min(x)>0) {

    # scale
    n <- length(x)
    scale <- n/sum(1/x)

    # df, MLE with Newton's method + optim
    f_nu <- function(nu) (n*(log(nu) - digamma(nu)) - (sum(log(x)) - n*log(scale)))^2
    res_optim <- stats::optim(1, f_nu, method = "BFGS")

    res <- list(scale = scale, df = 2*res_optim$par)
    return(res)

  } else stop(" Values must be strictely positive.")

}

median_invchisq <- function(df,scale=1/df){
  nu <- df/2
  #tau^2 = inverse variance σ^(-2) = scale
  res <- nu*scale/(nu+2)
  return(res)
}

#######################
#Parameters estimation
######################
fitdistrib <- function(x,pdistrib){
  res <- switch(pdistrib,
    "norm"   = fit_norm(x),
    "invchisq" = fit_invchisq(x),
    stop("distribution 'pdistrib' not yet included", pdistrib))
  return(res)
}

fit_norm <- function(x,pdistrib) {
  lmom <- lmom::samlmu(x)
  tmp <- lmom::pelnor(lmom)
  res <- stats::setNames(lapply(names(tmp), function(x) tmp[x]), names(tmp))
  return(res)
}

########################################################
# median processed with parameters from a distribution
########################################################
mediandistrib <- function(par,pdistrib){
  res <- switch(pdistrib,
    "norm"   = par[["mu"]],
    "invchisq" = median_invchisq(df=par[["df"]],scale=par[["scale"]]),
    stop("distribution 'pdistrib' not yet included", pdistrib))
  return(res)
}
